State

Trait State 

pub trait State: Sized {
    type NamespaceId;
    type SubspaceId;
    type Path;
    type Timestamp;
    type PayloadLength;
    type PayloadDigest;
}
Builder’s type state specifies if members are set or not (unset).

You can use the associated types of this trait to control the state of individual members with the IsSet and IsUnset traits. You can change the state of the members with the Set* structs available in this module.

Required Associated Types

type NamespaceId

Type state of the member namespace_id.

It can implement either IsSet or IsUnset

type SubspaceId

Type state of the member subspace_id.

It can implement either IsSet or IsUnset

type Path

Type state of the member path.

It can implement either IsSet or IsUnset

type Timestamp

Type state of the member timestamp.

It can implement either IsSet or IsUnset

type PayloadLength

Type state of the member payload_length.

It can implement either IsSet or IsUnset

type PayloadDigest

Type state of the member payload_digest.

It can implement either IsSet or IsUnset

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors