EntryBuilder

Struct EntryBuilder 

pub struct EntryBuilder<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, State: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, State: State> EntryBuilder<MCL, MCC, MPL, N, S, PD, State>

pub fn build(self) -> Entry<MCL, MCC, MPL, N, S, PD>
where State: IsComplete,

Finish building and return the requested object

pub fn namespace_id( self, value: N, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetNamespaceId<State>>

Required.

pub fn subspace_id( self, value: S, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetSubspaceId<State>>

Required.

pub fn path( self, value: Path<MCL, MCC, MPL>, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetPath<State>>

Required.

pub fn timestamp( self, value: impl Into<Timestamp>, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetTimestamp<State>>

Required.

pub fn payload_length( self, value: u64, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetPayloadLength<State>>

Required.

pub fn payload_digest( self, value: PD, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetPayloadDigest<State>>

Required.

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, State: State> EntryBuilder<MCL, MCC, MPL, N, S, PD, State>

pub fn now( self, ) -> Result<EntryBuilder<MCL, MCC, MPL, N, S, PD, SetTimestamp<State>>, HifitimeError>

Sets the timestamp of the entry being built to the current time.

pub fn payload<Payload, H, Digest>( self, payload: Payload, ) -> EntryBuilder<MCL, MCC, MPL, N, S, PD, SetPayloadLength<SetPayloadDigest<State>>>
where Payload: AsRef<[u8]>, H: Default + Hasher<Digest>, Digest: Into<PD>,

Sets the payload_length and payload_digest of the entry being built to those of the given Payload.

The type parameter H is the type of the Hasher which hashes the payload into a payload digest (of type Digest: Into<PD>). Its Default impl provides the initial state of the hasher.

pub async fn payload_async<P, H, Digest>( self, payload_producer: &mut P, ) -> Result<EntryBuilder<MCL, MCC, MPL, N, S, PD, SetPayloadLength<SetPayloadDigest<State>>>, P::Error>
where P: BulkProducer<Item = u8, Final = ()>, H: Default + Hasher<Digest>, Digest: Into<PD>,

Sets the payload_length and payload_digest of the entry being built to those of the payload given by the producer.

The type parameter H is the type of the Hasher which hashes the payload into a payload digest (of type Digest: Into<PD>). Its Default impl provides the initial state of the hasher.