pub enum EntryIngestionSuccess<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> {
Success,
Obsolete {
obsolete: AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>,
newer: AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>,
},
}Expand description
Returned when an entry could be ingested into a Store.
Variants
Success
The entry was successfully ingested.
Obsolete
The entry was not ingested because a newer entry with same
Fields

obsolete: AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>The obsolete entry which was not ingested.

newer: AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>The newer entry which was not overwritten.