pub enum EntryOrigin {
Local,
Remote(u64),
}Expand description
The origin of an entry ingestion event.
Variants
Local
The entry was probably created on this machine.
Remote(u64)
The entry was sourced from another source with an ID assigned by us. This is useful if you want to suppress the forwarding of entries to the peers from which the entry was originally sourced.