Module grouping

Utilities for Willow’s entry groupings.

Structs

Area
A grouping of entries. Definition.
AreaOfInterest
A grouping of crate::Entrys that are among the newest in some store.
Range
One-dimensional grouping over a type of value.
Range3d
A three-dimensional range that includes every Entry included in all three of its ranges. Definition.

Enums

AreaSubspace
The possible values of an Area’s subspace.
RangeEnd
Determines whether a Range is closed or open.