Struct Range3d

pub struct Range3d<const MCL: usize, const MCC: usize, const MPL: usize, S: SubspaceId> { /* private fields */ }
A three-dimensional range that includes every Entry included in all three of its ranges. Definition.

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S: SubspaceId> Range3d<MCL, MCC, MPL, S>

pub fn new( subspaces: Range<S>, paths: Range<Path<MCL, MCC, MPL>>, times: Range<Timestamp>, ) -> Self

Create a new Range3d.

pub fn subspaces(&self) -> &Range<S>

Return a reference to the range of SubspaceIds. Definition.

pub fn paths(&self) -> &Range<Path<MCL, MCC, MPL>>

Return a reference to the range of Paths. Definition.

pub fn times(&self) -> &Range<Timestamp>

Return a reference to the range of Timestamps. Definition.

pub fn includes_entry<N: NamespaceId, PD: PayloadDigest>( &self, entry: &Entry<MCL, MCC, MPL, N, S, PD>, ) -> bool

Return whether an Entry is included by this 3d range.

pub fn intersection(&self, other: &Range3d<MCL, MCC, MPL, S>) -> Option<Self>

Return the intersection between this Range3d and another.