WillowRange

Enum WillowRange 

pub enum WillowRange<T> {
    Closed(Range<T>),
    Open(RangeFrom<T>),
}
A continuous subset of a type implementing Ord.

It is either a closed range consisting of an inclusive start value and an exclusive end value, or an open range consisting only of an inclusive start value.

use std::ops::RangeBounds;
use willow_data_model::prelude::*;

assert!(WillowRange::<u8>::from(4..9).contains(&6));
assert!(!WillowRange::<u8>::from(4..9).contains(&12));

// You can create `WillowRanges` from arbitrary Rust ranges.
assert!(WillowRange::<u8>::from(4..=8) == WillowRange::<u8>::from(4..9));

Variants



Closed(Range<T>)

A closed range with an inclusive start value and an exclusive end value.



Open(RangeFrom<T>)

An open range with an inclusive start value.

Implementations

Source

impl<T> WillowRange<T>

pub fn includes_range<R: RangeBounds<T>>(&self, other: &R) -> bool

Returns whether every possible item that is included in other is also included in self.

If other is a WillowRange, you can equivalently check self >= other.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(4..9).includes_range(&(5..7)), true);
assert_eq!(WillowRange::<u8>::from(4..9).includes_range(&(5..11)), false);
assert_eq!(WillowRange::<u8>::from(4..9).includes_range(&(2..7)), false);
assert_eq!(WillowRange::<u8>::from(4..9).includes_range(&(4..9)), true);
pub fn strictly_includes_range<R: RangeBounds<T>>(&self, other: &R) -> bool

Returns whether every possible item that is included in other is also included in self and there exists at least one item included in self but not included in other.

If other is a WillowRange, you can equivalently check self > other.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(5..7)), true);
assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(5..11)), false);
assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(2..7)), false);
assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(4..9)), false);
assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(5..9)), true);
assert_eq!(WillowRange::<u8>::from(4..9).strictly_includes_range(&(4..8)), true);
pub fn does_intersection_include_value<R: RangeBounds<T>>( &self, other: &R, value: &T, ) -> bool

Returns whether the intersection of self and other includes the given value.

More efficient than actually creating the intersection and then calling includes.

use willow_data_model::prelude::*;

assert!(WillowRange::<u8>::from(4..9).does_intersection_include_value(&(5..7), &6));
assert!(!WillowRange::<u8>::from(4..9).does_intersection_include_value(&(5..7), &4));
assert!(!WillowRange::<u8>::from(4..9).does_intersection_include_value(&(5..7), &8));
assert!(!WillowRange::<u8>::from(4..9).does_intersection_include_value(&(5..7), &99));
Source

impl<T> WillowRange<T>

pub fn from_bounds<R>(bounds: &R) -> Self
where R: RangeBounds<T>,

Converts any value which implements RangeBounds<T> into a WillowRange<T> containing the same values.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from_bounds(&(..)), (..).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(0..)), (0..).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(..254)), (..254).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(..255)), (..255).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(..=254)), (..=254).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(..=255)), (..=255).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(4..8)), (4..8).into());
assert_eq!(WillowRange::<u8>::from_bounds(&(4..=8)), (4..=8).into());
pub fn intersection<R: RangeBounds<T>>(&self, other: &R) -> Self

Returns the intersection of self and other, i.e., the WillowRange which includes exactly those values included in both self and other.

If you want to check whether some value is included in the intersecion of two ranges, prefer WillowRange::does_intersection_include_value over explicitly constructing the intersection.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(4..9).intersection(&(5..7)), (5..7).into());
assert_eq!(WillowRange::<u8>::from(4..9).intersection(&(5..11)), (5..9).into());
assert_eq!(WillowRange::<u8>::from(4..9).intersection(&(2..7)), (4..7).into());
assert!(WillowRange::<u8>::from(4..9).intersection(&(11..14)).is_empty());
assert!(WillowRange::<u8>::from(4..9).intersection(&(6..6)).is_empty());
Source

impl<T> WillowRange<T>

pub fn is_closed(&self) -> bool

Returns whether self is a closed range.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).is_closed(), true);
assert_eq!(WillowRange::<u8>::from(3..255).is_closed(), true);
assert_eq!(WillowRange::<u8>::from(3..=255).is_closed(), false);
assert_eq!(WillowRange::<u8>::from(3..).is_closed(), false);
pub fn is_open(&self) -> bool

Returns whether self is an open range.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).is_open(), false);
assert_eq!(WillowRange::<u8>::from(3..255).is_open(), false);
assert_eq!(WillowRange::<u8>::from(3..=255).is_open(), true);
assert_eq!(WillowRange::<u8>::from(3..).is_open(), true);
pub fn start(&self) -> &T

Returns a reference to the start value of self.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).start(), &3);
assert_eq!(WillowRange::<u8>::from(..8).start(), &0);
pub fn start_mut(&mut self) -> &mut T

Returns a mutable reference to the start value of self.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).start_mut(), &mut 3);
assert_eq!(WillowRange::<u8>::from(..8).start_mut(), &mut 0);
pub fn end(&self) -> Option<&T>

Returns a reference to the end value of self, or None if the range is open.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).end(), Some(&8));
assert_eq!(WillowRange::<u8>::from(3..=8).end(), Some(&9));
assert_eq!(WillowRange::<u8>::from(3..).end(), None);
pub fn end_mut(&mut self) -> Option<&mut T>

Returns a mutable reference to the end value of self, or None if the range is open.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(3..8).end_mut(), Some(&mut 8));
assert_eq!(WillowRange::<u8>::from(3..=8).end_mut(), Some(&mut 9));
assert_eq!(WillowRange::<u8>::from(3..).end_mut(), None);
pub fn map<U, F>(self, f: F) -> WillowRange<U>
where F: FnMut(T) -> U,

Converts this range into a different range by applying a function to all endpoints.

use willow_data_model::prelude::*;

assert_eq!(
    WillowRange::<u8>::from(3..8).map(|x| (x + 1) as u16),
    WillowRange::<u16>::from(4..9),
);
pub unsafe fn cast<U>(&self) -> &WillowRange<U>

Unsafely reinterprets a reference to a range as a reference to a range of a different type of boundaries.

Safety

This is safe only if &T and &U have an identical layout in memory.

Source

impl<T> WillowRange<T>
where T: Ord,

pub fn is_empty(&self) -> bool

Returns whether self is empty, i.e., whether it includes no values.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::from(4..5).is_empty(), false);
assert_eq!(WillowRange::<u8>::from(255..).is_empty(), false);
assert_eq!(WillowRange::<u8>::from(4..4).is_empty(), true);
assert_eq!(WillowRange::<u8>::from(4..3).is_empty(), true);
Source

impl<T> WillowRange<T>

pub fn singleton(t: T) -> Self

Returns the WillowRange which includes t but no other value.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::singleton(5), (5..6).into());
assert_eq!(WillowRange::<u8>::singleton(255), (255..).into());
Source

impl<T> WillowRange<T>
where T: LeastElement,

pub fn full() -> Self

Returns the WillowRange which includes every value of type T.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::full(), (..).into());
pub fn is_full(&self) -> bool

Returns whether self is the full range, i.e., the range which includes every value of type T.

use willow_data_model::prelude::*;

assert_eq!(WillowRange::<u8>::full().is_full(), true);
assert_eq!(WillowRange::<u8>::from(1..).is_full(), false);
assert_eq!(WillowRange::<u8>::from(0..255).is_full(), false);