pub struct PrivateInterest<const MCL: usize, const MCC: usize, const MPL: usize, N, S> { /* private fields */ }Expand description
Confidential data that relates to determining the AreaOfInterest that peers might be interested in synchronising.
Implementations
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S> PrivateInterest<MCL, MCC, MPL, N, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S> PrivateInterest<MCL, MCC, MPL, N, S>
Sourcepub fn new(
namespace_id: N,
subspace_id: Option<S>,
path: Path<MCL, MCC, MPL>,
) -> Self
pub fn new( namespace_id: N, subspace_id: Option<S>, path: Path<MCL, MCC, MPL>, ) -> Self
Returns a new PrivateInterest with the gives attributes.
Sourcepub fn namespace(&self) -> &N
pub fn namespace(&self) -> &N
Returns the Namespace ID of this PrivateInterest.
Sourcepub fn subspace(&self) -> Option<&S>
pub fn subspace(&self) -> Option<&S>
Returns the specific SubspaceId of this PrivateInterest, if present. None denotes interest in all subspaces of the namespace.
Sourcepub fn path(&self) -> &Path<MCL, MCC, MPL>
pub fn path(&self) -> &Path<MCL, MCC, MPL>
Returns the path of this PrivateInterest.
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N: PartialEq, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N: PartialEq, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
Sourcepub fn is_more_specific(&self, other: &Self) -> bool
pub fn is_more_specific(&self, other: &Self) -> bool
Returns true is this PrivateInterest is more specific than other.
Sourcepub fn is_disjoint(&self, other: &Self) -> bool
pub fn is_disjoint(&self, other: &Self) -> bool
Returns true is this PrivateInterest is disjoint from other, namely that there is no Entry which can be included in both.
Sourcepub fn is_less_specific(&self, other: &Self) -> bool
pub fn is_less_specific(&self, other: &Self) -> bool
Returns true is this PrivateInterest is less specific than other.
Sourcepub fn is_comparable(&self, other: &Self) -> bool
pub fn is_comparable(&self, other: &Self) -> bool
Returns true is this PrivateInterest is comparable to other.
Sourcepub fn are_awkward(&self, other: &Self) -> bool
pub fn are_awkward(&self, other: &Self) -> bool
Returns true if self and other are awkward, meaning they are neither comparable nor disjoint.
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N: PartialEq, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N: PartialEq, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S: PartialEq + Clone> PrivateInterest<MCL, MCC, MPL, N, S>
Sourcepub fn includes_area(&self, area: &Area<MCL, MCC, MPL, S>) -> bool
pub fn includes_area(&self, area: &Area<MCL, MCC, MPL, S>) -> bool
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S: PartialEq> PrivateInterest<MCL, MCC, MPL, N, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S: PartialEq> PrivateInterest<MCL, MCC, MPL, N, S>
Sourcepub fn almost_includes_area(&self, area: &Area<MCL, MCC, MPL, S>) -> bool
pub fn almost_includes_area(&self, area: &Area<MCL, MCC, MPL, S>) -> bool
Returns true if self almost includes the given Area.