Area

Struct Area 

pub struct Area<const MCL: usize, const MCC: usize, const MPL: usize, S> { /* private fields */ }
An Area is a box in three-dimensional willow space, consisting of all entries matching either a single subspace id or entries of arbitrary subspace ids, prefixed by some Path, and a TimeRange.

Areas are the default way by which application developers should aggregate entries. See the specification for more details.

use willow_data_model::prelude::*;

let a1 = Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17));

assert!(a1.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert_eq!(a1.subspace(), None);

let a2 = Area::<2, 2, 2, u8>::new(Some(42), Path::new(), Timestamp::from(15)..);
assert_eq!(
    a1.wdm_intersection(&a2),
    Area::<2, 2, 2, u8>::new(
        Some(42),
        Path::new(),
        Timestamp::from(15)..Timestamp::from(17),
    ),
);

Specification

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Area<MCL, MCC, MPL, S>

pub fn new<TR>( subspace: Option<S>, path: Path<MCL, MCC, MPL>, times: TR, ) -> Self
where TR: Into<TimeRange>,

Creates a new Area from its constituent optional subspace id, Path, and TimeRange.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17));

assert!(a.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert_eq!(a.subspace(), None);
pub fn subspace(&self) -> Option<&S>

Returns a reference to the inner subspace id, if any.

use willow_data_model::prelude::*;

let a1 = Area::<2, 2, 2, u8>::new(Some(17), Path::new(), ..Timestamp::from(17));
assert_eq!(a1.subspace(), Some(&17));

let a2 = Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17));
assert_eq!(a2.subspace(), None);

Definition.

pub fn path(&self) -> &Path<MCL, MCC, MPL>

Returns a reference to the inner Path.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::new(Some(17), Path::new(), ..Timestamp::from(17));
assert_eq!(a.path(), &Path::new());

Definition.

pub fn times(&self) -> &TimeRange

Returns a reference to the inner TimeRange.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::new(Some(17), Path::new(), ..Timestamp::from(17));
assert_eq!(a.times(), &WillowRange::from(..Timestamp::from(17)));

Definition.

pub fn set_subspace(&mut self, new_subspace: Option<S>)

Sets the inner subspace id.

pub fn set_path(&mut self, new_path: Path<MCL, MCC, MPL>)

Sets the inner Path.

pub fn set_times<TR>(&mut self, new_range: TR)
where TR: Into<TimeRange>,

Sets the inner TimeRange.

pub fn new_subspace(subspace_id: S) -> Self

Returns the subspace area for the given subspace id, i.e., the area which includes exactly the entries of the given subspace id.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::new_subspace(17);

assert!(a.wdm_includes(&(17, Path::new(), Timestamp::from(9))));
assert!(!a.wdm_includes(&(18, Path::new(), Timestamp::from(9))));
assert_eq!(a.subspace(), Some(&17));
Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Area<MCL, MCC, MPL, S>

pub fn admits_pruning_by<Coord>(&self, coord: &Coord) -> bool
where Coord: Coordinatelike<MCL, MCC, MPL, S>,

Returns whether an Entry of the given coordinate could possibly cause prefix pruning in this area.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::new(Some(17), Path::new(), ..Timestamp::from(17));

assert!(a.admits_pruning_by(&(17, Path::new(), Timestamp::from(9))));
assert!(!a.admits_pruning_by(&(18, Path::new(), Timestamp::from(9))));
Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Area<MCL, MCC, MPL, S>

pub fn full() -> Self

Returns the Area which includes every coordinate.

use willow_data_model::prelude::*;

let a = Area::<2, 2, 2, u8>::full();

assert!(a.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert!(a.wdm_includes(&(16, Path::new(), Timestamp::from(9))));
pub fn is_full(&self) -> bool

Returns whether self is the full area, i.e., the area which includes every coordinate.

use willow_data_model::prelude::*;

assert!(Area::<2, 2, 2, u8>::full().is_full());
assert!(!Area::<2, 2, 2, u8>::new(Some(17), Path::new(), ..Timestamp::from(17)).is_full());