AreaOfInterest

Struct AreaOfInterest 

pub struct AreaOfInterest<const MCL: usize, const MCC: usize, const MPL: usize, S> { /* private fields */ }
An AreaOfInterest is an Area together with a maximum number of entries it may include, and a maximum sum of total payload_lengths for the included entries.

A max_count of u64::MAX indicates that there is no limit on the number of entries. A max_size of u64::MAX indicates that there is no limit on the total payload_lengths of the entries.

use willow_data_model::prelude::*;

let aoi = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);

assert_eq!(aoi.area(), &Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)));
assert_eq!(aoi.max_count(), 5);
assert_eq!(aoi.max_size(), 400);

Specification

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> AreaOfInterest<MCL, MCC, MPL, S>

pub fn new(area: Area<MCL, MCC, MPL, S>, max_count: u64, max_size: u64) -> Self

Creates a new AreaOfInterest from its constituent Area, max_count, and max_size.

A max_count of u64::MAX indicates that there is no limit on the number of entries. A max_size of u64::MAX indicates that there is no limit on the total payload_lengths of the entries.

use willow_data_model::prelude::*;

let aoi = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);

assert_eq!(
    aoi.area(),
    &Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
);
assert_eq!(aoi.max_count(), 5);
assert_eq!(aoi.max_size(), 400);
pub fn area(&self) -> &Area<MCL, MCC, MPL, S>

Returns a reference to the inner Area.

use willow_data_model::prelude::*;

let aoi = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);
assert_eq!(aoi.area(), &Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)));

Definition.

pub fn max_count(&self) -> u64

Returns the max_count of entries.

A max_count of u64::MAX indicates that there is no limit on the number of entries in this area of interest.

use willow_data_model::prelude::*;

let aoi = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);
assert_eq!(aoi.max_count(), 5);

Definition.

pub fn max_size(&self) -> u64

Returns the max_count of entries.

A max_size of u64::MAX indicates that there is no limit on the total payload_lengths of the entries in this area of interest.

use willow_data_model::prelude::*;

let aoi = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);
assert_eq!(aoi.max_size(), 400);

Definition.

pub fn set_area(&mut self, new_area: Area<MCL, MCC, MPL, S>)

Sets the inner area.

pub fn set_max_count(&mut self, new_max_count: u64)

Sets the max_count.

A max_count of u64::MAX indicates that there is no limit on the number of entries in this area of interest.

pub fn set_max_size(&mut self, new_max_size: u64)

Sets the max_size.

A max_size of u64::MAX indicates that there is no limit on the total payload_lengths of the entries in this area of interest.

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> AreaOfInterest<MCL, MCC, MPL, S>

pub fn is_empty(&self) -> bool

Returns true iff this area of interest cannot possibly contain any entries.

use willow_data_model::prelude::*;

assert!(
    !AreaOfInterest::new(
        Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
        5,
        400,
    ).is_empty(),
);
assert!(
    !AreaOfInterest::new(
        Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
        5,
        0, // Could still possibly contain entries with a payload_length of zero.
    ).is_empty(),
);

assert!(
    AreaOfInterest::new(
        Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
        0,
        400,
    ).is_empty(),
);
assert!(
    AreaOfInterest::new(
        Area::<2, 2, 2, u8>::wdm_empty(),
        5,
        400,
    ).is_empty(),
);
pub fn intersection(&self, other: &Self) -> Self

Returns the intersection of self and other.

use willow_data_model::prelude::*;

let aoi1 = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), ..Timestamp::from(17)),
    5,
    400,
);
let aoi2 = AreaOfInterest::new(
    Area::<2, 2, 2, u8>::new(None, Path::new(), Timestamp::from(14)..),
    12,
    32,
);

assert_eq!(
    aoi1.intersection(&aoi2),
    AreaOfInterest::new(
        Area::<2, 2, 2, u8>::new(
            None,
            Path::new(),
            Timestamp::from(14)..Timestamp::from(17),
        ),
        5,
        32,
    ),
);