Range3d

Struct Range3d 

pub struct Range3d<const MCL: usize, const MCC: usize, const MPL: usize, S> { /* private fields */ }
An arbitrary box in three-dimensional willow space, consisting of a SubspaceRange, a PathRange, and a TimeRange.

As an application developer, you probably do not need to interact with 3d ranges, you should prefer Areas — the latter work well with encrypted data, whereas 3d ranges do not define human-meaningful subsets of data when working with encryption.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17));

assert!(r.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert_eq!(r.subspaces(), &WillowRange::from(5u8..9));

let r2 = Range3d::<2, 2, 2, u8>::new(7..8, .., Timestamp::from(15)..);
assert_eq!(
    r.wdm_intersection(&r2),
    Range3d::<2, 2, 2, u8>::new(7..8, .., Timestamp::from(15)..Timestamp::from(17)),
);

Specification

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Range3d<MCL, MCC, MPL, S>

pub fn new<SR, PR, TR>(subspaces: SR, paths: PR, times: TR) -> Self
where SR: Into<SubspaceRange<S>>, PR: Into<PathRange<MCL, MCC, MPL>>, TR: Into<TimeRange>,

Creates a new Range3d from its constituent SubspaceRange, PathRange, and TimeRange.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17));

assert!(r.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert_eq!(r.subspaces(), &WillowRange::from(5u8..9));
pub fn subspaces(&self) -> &SubspaceRange<S>

Returns a reference to the inner SubspaceRange.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17));
assert_eq!(r.subspaces(), &SubspaceRange::from(5u8..9));

Definition.

pub fn paths(&self) -> &PathRange<MCL, MCC, MPL>

Returns a reference to the inner PathRange.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17));
assert_eq!(r.paths(), &WillowRange::full());

Definition.

pub fn times(&self) -> &TimeRange

Returns a reference to the inner TimeRange.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17));
assert_eq!(r.times(), &WillowRange::from(..Timestamp::from(17)));

Definition.

pub fn set_subspaces<SR>(&mut self, new_range: SR)
where SR: Into<SubspaceRange<S>>,

Sets the inner SubspaceRange.

pub fn set_paths<PR>(&mut self, new_range: PR)
where PR: Into<PathRange<MCL, MCC, MPL>>,

Sets the inner PathRange.

pub fn set_times<TR>(&mut self, new_range: TR)
where TR: Into<TimeRange>,

Sets the inner TimeRange.

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Range3d<MCL, MCC, MPL, S>

pub fn singleton<Coord>(coord: &Coord) -> Self
where Coord: Coordinatelike<MCL, MCC, MPL, S>,

Returns the Range3d which includes coord but no other value.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::singleton(&(6, Path::new(), Timestamp::from(9)));

assert!(r.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert!(!r.wdm_includes(&(16, Path::new(), Timestamp::from(9))));
Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, S> Range3d<MCL, MCC, MPL, S>

pub fn full() -> Self

Returns the Range3d which includes every coordinate.

use willow_data_model::prelude::*;

let r = Range3d::<2, 2, 2, u8>::full();

assert!(r.wdm_includes(&(6, Path::new(), Timestamp::from(9))));
assert!(r.wdm_includes(&(16, Path::new(), Timestamp::from(9))));
pub fn is_full(&self) -> bool

Returns whether self is the full 3d range, i.e., the 3d range which includes every coordinate.

use willow_data_model::prelude::*;

assert!(Range3d::<2, 2, 2, u8>::full().is_full());
assert!(!Range3d::<2, 2, 2, u8>::new(5..=8, .., ..Timestamp::from(17)).is_full());