Module private

Module private 

Module providing abstractions for PrivatePathContexts, which facilitate private encodings. The PrivatePathContext is the common context between two parties which makes it possible to decode a private encoding. You probably don’t need to interact with this unless you are building your own private encoding scheme.

Structs

ComponentsNotRelatedError
An error arising from trying to construct an invalid PrivatePathContext
PrivatePathContext
The immutable PrivatePathContext necessary to privately encode a Path relative to one of its prefixes, while keeping secret all Components that coincide with a third Path.