PrivatePathContext

Struct PrivatePathContext 

pub struct PrivatePathContext<const MCL: usize, const MCC: usize, const MPL: usize> { /* private fields */ }
The immutable PrivatePathContext necessary to privately encode a Path relative to one of its prefixes, while keeping secret all Components that coincide with a third Path.

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize> PrivatePathContext<MCL, MCC, MPL>

pub fn new( private: Path<MCL, MCC, MPL>, rel: Path<MCL, MCC, MPL>, ) -> Result<Self, ComponentsNotRelatedError>

Returns a new PrivatePathContext with the given private and relative paths.

Will return a ComponentsNotRelatedError if the given private and relative paths are not related.

pub unsafe fn new_unchecked( private: Path<MCL, MCC, MPL>, rel: Path<MCL, MCC, MPL>, ) -> Self

Returns a new PrivatePathContext with the given private and relative paths without checking if the given private and relative paths are related.

Safety

Undefined behaviour if private and rel are not related.

pub fn private(&self) -> &Path<MCL, MCC, MPL>

Returns the private path of &self.

pub fn rel(&self) -> &Path<MCL, MCC, MPL>

Returns the relative path of &self.