pub struct AuthorisedEntry<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT>(/* private fields */);Expand description
An AuthorisedEntry is a pair of an Entry and AuthorisationToken for which AuthorisationToken::is_authorised_write returns true.
Implementations
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
Sourcepub fn new(
entry: Entry<MCL, MCC, MPL, N, S, PD>,
token: AT,
) -> Result<Self, UnauthorisedWriteError>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
pub fn new(
entry: Entry<MCL, MCC, MPL, N, S, PD>,
token: AT,
) -> Result<Self, UnauthorisedWriteError>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
Returns an AuthorisedEntry if the token permits the writing of this entry, otherwise returns an UnauthorisedWriteError.
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>
Sourcepub unsafe fn new_unchecked(
entry: Entry<MCL, MCC, MPL, N, S, PD>,
token: AT,
) -> Self
pub unsafe fn new_unchecked( entry: Entry<MCL, MCC, MPL, N, S, PD>, token: AT, ) -> Self
Returns an AuthorisedEntry without checking if the token permits the writing of this entry.
Safety
Calling this method when token.is_authorised_write(&entry) would return false is immediate undefined behaviour!
Sourcepub fn into_parts(self) -> (Entry<MCL, MCC, MPL, N, S, PD>, AT)
pub fn into_parts(self) -> (Entry<MCL, MCC, MPL, N, S, PD>, AT)
Splits this into Entry and AuthorisationToken halves.
Sourcepub fn token(&self) -> &AT
pub fn token(&self) -> &AT
Gets a reference to the AuthorisationToken.