Struct Entry

pub struct Entry<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD>{ /* private fields */ }
The metadata associated with each Payload. Definition.

Implementations

Source

impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD> Entry<MCL, MCC, MPL, N, S, PD>

pub fn new( namespace_id: N, subspace_id: S, path: Path<MCL, MCC, MPL>, timestamp: Timestamp, payload_length: u64, payload_digest: PD, ) -> Self

Create a new Entry.

pub fn namespace_id(&self) -> &N

Return a reference to the identifier of the namespace to which the Entry belongs.

pub fn subspace_id(&self) -> &S

Return a reference to the identifier of the subspace_id to which the Entry belongs.

pub fn path(&self) -> &Path<MCL, MCC, MPL>

Return a reference to the Path to which the Entry was written.

pub fn timestamp(&self) -> Timestamp

Return the claimed creation time of the Entry.

pub fn payload_length(&self) -> u64

Return the length of the Payload in bytes.

pub fn payload_digest(&self) -> &PD

Return a reference to the result of applying hash_payload to the Payload.

pub fn is_newer_than(&self, other: &Self) -> bool

Return if this Entry is newer than another using their timestamps. Tie-breaks using the Entries’ payload digest and payload length otherwise. Definition.