Trait AuthorisationToken

pub trait AuthorisationToken<const MCL: usize, const MCC: usize, const MPL: usize, N: NamespaceId, S: SubspaceId, PD: PayloadDigest> {
    // Required method
    fn is_authorised_write(
        &self,
        entry: &Entry<MCL, MCC, MPL, N, S, PD>,
    ) -> bool;
}
Determines whether this type (nominally a AuthorisationToken) is able to prove write permission for a given Entry.

Type parameters

Required Methods

fn is_authorised_write(&self, entry: &Entry<MCL, MCC, MPL, N, S, PD>) -> bool

Determine whether this type (nominally a AuthorisationToken) is able to prove write permission for a given Entry.

Implementors