pub struct AreaOfInterest<const MCL: usize, const MCC: usize, const MPL: usize, S: SubspaceId> {
pub area: Area<MCL, MCC, MPL, S>,
pub max_count: u64,
pub max_size: u64,
}Expand description
A grouping of crate::Entrys that are among the newest in some store.
Fields
area: Area<MCL, MCC, MPL, S>To be included in this AreaOfInterest, an crate::Entry must be included in the Area.
max_count: u64To be included in this AreaOfInterest, an Entry’s timestamp must be among the max_count greatest Timestamps, unless max_count is zero.
max_size: u64The total payload_lengths of all included Entries is at most max_size, unless max_size is zero.
Implementations
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, S: SubspaceId> AreaOfInterest<MCL, MCC, MPL, S>
impl<const MCL: usize, const MCC: usize, const MPL: usize, S: SubspaceId> AreaOfInterest<MCL, MCC, MPL, S>
Sourcepub fn intersection(
&self,
other: AreaOfInterest<MCL, MCC, MPL, S>,
) -> Option<AreaOfInterest<MCL, MCC, MPL, S>>
pub fn intersection( &self, other: AreaOfInterest<MCL, MCC, MPL, S>, ) -> Option<AreaOfInterest<MCL, MCC, MPL, S>>
Return the intersection of this AreaOfInterest with another.
Definition.