pub struct AuthorisedEntry<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT>(pub Entry<MCL, MCC, MPL, N, S, PD>, pub AT)
where
N: NamespaceId,
S: SubspaceId,
PD: PayloadDigest;Expand description
An AuthorisedEntry is a pair of an Entry and AuthorisationToken for which [Entry::is_authorised_write] returns true.
Definition.
Tuple Fields
0: Entry<MCL, MCC, MPL, N, S, PD>1: ATImplementations
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD, AT> AuthorisedEntry<MCL, MCC, MPL, N, S, PD, AT>
Sourcepub fn new(
entry: Entry<MCL, MCC, MPL, N, S, PD>,
token: AT,
) -> Result<Self, UnauthorisedWriteError>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
pub fn new(
entry: Entry<MCL, MCC, MPL, N, S, PD>,
token: AT,
) -> Result<Self, UnauthorisedWriteError>where
AT: AuthorisationToken<MCL, MCC, MPL, N, S, PD>,
Construct an AuthorisedEntry if the token permits the writing of this entry, otherwise return an UnauthorisedWriteError