pub struct Entry<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD>{ /* private fields */ }Expand description
The metadata associated with each Payload. Definition.
Implementations
Sourceimpl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD> Entry<MCL, MCC, MPL, N, S, PD>
impl<const MCL: usize, const MCC: usize, const MPL: usize, N, S, PD> Entry<MCL, MCC, MPL, N, S, PD>
Sourcepub fn new(
namespace_id: N,
subspace_id: S,
path: Path<MCL, MCC, MPL>,
timestamp: Timestamp,
payload_length: u64,
payload_digest: PD,
) -> Self
pub fn new( namespace_id: N, subspace_id: S, path: Path<MCL, MCC, MPL>, timestamp: Timestamp, payload_length: u64, payload_digest: PD, ) -> Self
Create a new Entry.
Sourcepub fn namespace_id(&self) -> &N
pub fn namespace_id(&self) -> &N
Return a reference to the identifier of the namespace to which the Entry belongs.
Sourcepub fn subspace_id(&self) -> &S
pub fn subspace_id(&self) -> &S
Return a reference to the identifier of the subspace_id to which the Entry belongs.
Sourcepub fn payload_length(&self) -> u64
pub fn payload_length(&self) -> u64
Return the length of the Payload in bytes.
Sourcepub fn payload_digest(&self) -> &PD
pub fn payload_digest(&self) -> &PD
Return a reference to the result of applying hash_payload to the Payload.
Sourcepub fn is_newer_than(&self, other: &Self) -> bool
pub fn is_newer_than(&self, other: &Self) -> bool
Return if this Entry is newer than another using their timestamps.
Tie-breaks using the Entries’ payload digest and payload length otherwise.
Definition.