pub trait AuthorisationToken<const MCL: usize, const MCC: usize, const MPL: usize, N: NamespaceId, S: SubspaceId, PD: PayloadDigest> {
// Required method
fn is_authorised_write(
&self,
entry: &Entry<MCL, MCC, MPL, N, S, PD>,
) -> bool;
}Expand description
Determines whether this type (nominally a AuthorisationToken) is able to prove write permission for a given Entry.
Type parameters
N- The type used for theEntry’sNamespaceId.S- The type used for theEntry’sSubspaceId.PD- The type used for theEntry’sPayloadDigest.
Required Methods
Determine whether this type (nominally a AuthorisationToken) is able to prove write permission for a given Entry.