pub trait SubspaceId:
Ord
+ Default
+ Clone {
// Required method
fn successor(&self) -> Option<Self>;
}Expand description
A type for identifying subspaces. Definition.
Implementation notes
The Default implementation must return the least element in the total order of SubspaceId.
Required Methods
Sourcefn successor(&self) -> Option<Self>
fn successor(&self) -> Option<Self>
Return the next possible value in the set of all SubspaceId.
e.g. the successor of 3 is 4.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.